/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/file.h                                               *
 * Created:     2007-12-02 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2007-2012 Hampa Hug <hampa@hampa.ch>                     *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_FILE_H
#define MAC_LIB_FILE_H 1


#include <stdio.h>


/*!***************************************************************************
 * @short  Open a file for input
 * @param  name The file name or NULL
 * @param  mode The file mode as for fopen(3)
 * @param  std  If true and name is NULL, return stdin instead of NULL
 *****************************************************************************/
FILE *mac_open_out (const char *name, const char *mode, int std);

/*!***************************************************************************
 * @short  Open a file for output
 * @param  name The file name or NULL
 * @param  mode The file mode as for fopen(3)
 * @param  std  If true and name is NULL, return stdout instead of NULL
 *****************************************************************************/
FILE *mac_open_inp (const char *name, const char *mode, int std);

/*!***************************************************************************
 * @short  Close a file
 * @param  fp The file pointer
 *****************************************************************************/
void mac_close (FILE *fp);

int mac_set_pos (FILE *fp, unsigned long ofs);

int mac_get_pos (FILE *fp, unsigned long *ofs);

int mac_read (FILE *fp, void *buf, unsigned long ofs, unsigned long cnt);

int mac_write (FILE *fp, const void *buf, unsigned long ofs, unsigned long cnt);


#endif
