/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/macbinary.h                                          *
 * Created:     2004-02-01 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2004-2009 Hampa Hug <hampa@hampa.ch>                     *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_MACBINARY_H
#define MAC_LIB_MACBINARY_H 1


#include <lib/macfile.h>


/* finder flags */
#define MB_FF_LOCKED    0x8000U
#define MB_FF_INVISIBLE 0x4000U
#define MB_FF_BUNDLE    0x2000U
#define MB_FF_SYSTEM    0x1000U
#define MB_FF_BOZO      0x0800U
#define MB_FF_BUSY      0x0400U
#define MB_FF_CHANGED   0x0200U
#define MB_FF_INITED    0x0100U


void mb_init (void *mb);

int mb_read (void *mb, FILE *fp);
int mb_write (const void *mb, FILE *fp);

unsigned short mb_calc_crc (const void *mb);

unsigned mb_get_version (const void *mb);

unsigned mb_get_id (const void *mb);
void mb_set_id (void *mb, unsigned id);

const unsigned char *mb_get_name_pstr (const void *mb);
int mb_set_name_pstr (void *mb, const void *str);

char *mb_get_name_cstr (const void *mb);
int mb_set_name_cstr (void *mb, const char *str);

unsigned long mb_get_type (const void *mb);
void mb_set_type (void *mb, unsigned long v);

unsigned long mb_get_creator (const void *mb);
void mb_set_creator (void *mb, unsigned long v);

unsigned short mb_get_finder_flags (const void *mb);
void mb_set_finder_flags (void *mb, unsigned short v);

unsigned short mb_get_position_y (const void *mb);
void mb_set_position_y (void *mb, unsigned short v);

unsigned short mb_get_position_x (const void *mb);
void mb_set_position_x (void *mb, unsigned short v);

unsigned short mb_get_folder_id (const void *mb);
void mb_set_folder_id (void *mb, unsigned short v);

unsigned short mb_get_folder_view (const void *mb);
void mb_set_folder_view (void *mb, unsigned short v);

unsigned char mb_get_file_flags (const void *mb);
void mb_set_file_flags (void *mb, unsigned char v);

unsigned long mb_get_data_size (const void *mb);
void mb_set_data_size (void *mb, unsigned long v);

unsigned long mb_get_rsrc_size (const void *mb);
void mb_set_rsrc_size (void *mb, unsigned long v);

unsigned long mb_get_ctime (const void *mb);
void mb_set_ctime (void *mb, unsigned long v);

unsigned long mb_get_mtime (const void *mb);
void mb_set_mtime (void *mb, unsigned long v);

unsigned mb_get_getinfo_size (const void *mb);
void mb_set_getinfo_size (void *mb, unsigned v);

unsigned short mb_get_scroll_y (const void *mb);
void mb_set_scroll_y (void *mb, unsigned short v);

unsigned short mb_get_scroll_x (const void *mb);
void mb_set_scroll_x (void *mb, unsigned short v);

unsigned mb_get_secondary_size (const void *mb);
void mb_set_secondary_size (void *mb, unsigned v);

unsigned mb_get_vers_read (const void *mb);
void mb_set_vers_read (void *mb, unsigned v);

unsigned mb_get_vers_write (const void *mb);
void mb_set_vers_write (void *mb, unsigned v);

unsigned short mb_get_crc (const void *mb);
void mb_set_crc (void *mb, unsigned short v);

void mb_get_macfile (const void *mb, macfile_t *mf);
void mb_set_macfile (void *mb, const macfile_t *mf);


#endif
