/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/macfile.h                                            *
 * Created:     2006-08-19 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2006-2011 Hampa Hug <hampa@hampa.ch>                     *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_MACFILE_H
#define MAC_LIB_MACFILE_H 1


/* finder flags */
#define MF_FINDER_ALIAS       0x8000U
#define MF_FINDER_INVISIBLE   0x4000U
#define MF_FINDER_BUNDLE      0x2000U
#define MF_FINDER_NAME_LOCKED 0x1000U
#define MF_FINDER_STATIONARY  0x0800U
#define MF_FINDER_CUSTOM_ICON 0x0400U
#define MF_FINDER_CHANGED     0x0200U
#define MF_FINDER_INITED      0x0100U
#define MF_FINDER_NOINITS     0x0080U
#define MF_FINDER_SHARED      0x0040U
#define MF_FINDER_COLOR4      0x0010U
#define MF_FINDER_COLOR3      0x0008U
#define MF_FINDER_COLOR2      0x0004U
#define MF_FINDER_COLOR1      0x0002U

/* system 6 finder flags */
#define MF_FINDER_LOCKED      0x8000U
#define MF_FINDER_SYSTEM      0x1000U
#define MF_FINDER_BOZO        0x0800U
#define MF_FINDER_BUSY        0x0400U
#define MF_FINDER_SWITCH      0x0020U
#define MF_FINDER_ONDESK      0x0001U

/* file flags */
#define MF_FILE_LOCKED    0x00000001
#define MF_FILE_PROTECTED 0x00000002
#define MF_FILE_ISDIR     0x00000010


typedef struct {
	unsigned char  name[256];

	unsigned long  data_size;
	unsigned long  rsrc_size;
	unsigned long  comment_size;

	unsigned long  file_type;
	unsigned long  file_creator;

	unsigned short finder_flags;
	unsigned long  file_flags;

	unsigned short position_x;
	unsigned short position_y;

	unsigned short folder_id;

	unsigned short scroll_x;
	unsigned short scroll_y;

	unsigned long  mtime;
	unsigned long  ctime;
} macfile_t;


void mf_init (macfile_t *mf);

const unsigned char *mf_get_name_pstr (const macfile_t *mf);
void mf_set_name_pstr (macfile_t *mf, const void *str);

char *mf_get_name_cstr (const macfile_t *mf);
int mf_set_name_cstr (macfile_t *mf, const char *val);

unsigned long mf_get_data_size (const macfile_t *mf);
void mf_set_data_size (macfile_t *mf, unsigned long val);

unsigned long mf_get_rsrc_size (const macfile_t *mf);
void mf_set_rsrc_size (macfile_t *mf, unsigned long val);

unsigned long mf_get_comment_size (const macfile_t *mf);
void mf_set_comment_size (macfile_t *mf, unsigned long val);

unsigned long mf_get_type (const macfile_t *mf);
void mf_set_type (macfile_t *mf, unsigned long val);

unsigned long mf_get_creator (const macfile_t *mf);
void mf_set_creator (macfile_t *mf, unsigned long val);

unsigned short mf_get_window_y1 (const macfile_t *mf);
void mf_set_window_y1 (macfile_t *mf, unsigned short val);

unsigned short mf_get_window_x1 (const macfile_t *mf);
void mf_set_window_x1 (macfile_t *mf, unsigned short val);

unsigned short mf_get_window_y2 (const macfile_t *mf);
void mf_set_window_y2 (macfile_t *mf, unsigned short val);

unsigned short mf_get_window_x2 (const macfile_t *mf);
void mf_set_window_x2 (macfile_t *mf, unsigned short val);

unsigned short mf_get_finder_flags (const macfile_t *mf);
void mf_set_finder_flags (macfile_t *mf, unsigned short val);

unsigned long mf_get_file_flags (const macfile_t *mf);
void mf_set_file_flags (macfile_t *mf, unsigned long val);

unsigned short mf_get_position_x (const macfile_t *mf);
void mf_set_position_x (macfile_t *mf, unsigned short val);

unsigned short mf_get_position_y (const macfile_t *mf);
void mf_set_position_y (macfile_t *mf, unsigned short val);

unsigned short mf_get_folder_id (const macfile_t *mf);
void mf_set_folder_id (macfile_t *mf, unsigned short val);

unsigned short mf_get_window_view (const macfile_t *mf);
void mf_set_window_view (macfile_t *mf, unsigned short val);

unsigned short mf_get_scroll_x (const macfile_t *mf);
void mf_set_scroll_x (macfile_t *mf, unsigned short val);

unsigned short mf_get_scroll_y (const macfile_t *mf);
void mf_set_scroll_y (macfile_t *mf, unsigned short val);

unsigned long mf_get_mtime (const macfile_t *mf);
void mf_set_mtime (macfile_t *mf, unsigned long val);

unsigned long mf_get_ctime (const macfile_t *mf);
void mf_set_ctime (macfile_t *mf, unsigned long val);

void mf_add_times (macfile_t *mf, long val);

const char *mf_finder_flag_to_string (unsigned short v);
unsigned short mf_finder_flag_from_string (const char *name);

const char *mf_file_flag_to_string (unsigned long v);
unsigned long mf_file_flag_from_string (const char *name);

void mf_save (macfile_t *mf, FILE *fp);
int mf_load (macfile_t *mf, FILE *fp);

void mf_print_info (macfile_t *mf, FILE *fp);


#endif
