/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/mar.h                                                *
 * Created:     2011-06-25 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2011 Hampa Hug <hampa@hampa.ch>                          *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_MAR_H
#define MAC_LIB_MAR_H 1


#include <lib/macfile.h>


#define MAR_MAGIC        0x4d415280

#define MAR_FILE         0x66696c65
#define MAR_FOLDER_START 0x666f6c64
#define MAR_FOLDER_END   0x2d2d2d2d


#define MAR_CRC_POLY     0x1edc6f41


void mar_init (void *mar);

int mar_read (void *mar, FILE *fp);
int mar_write (const void *mar, FILE *fp);

unsigned long mar_calc_crc (const void *buf, unsigned long cnt, unsigned long crc);

int mar_is_mar (const void *mar);

unsigned long mar_get_id (const void *mar);
void mar_set_id (void *mar, unsigned long v);

const unsigned char *mar_get_name_pstr (const void *mar);
int mar_set_name_pstr (void *mar, const void *str);

char *mar_get_name_cstr (const void *mar);
int mar_set_name_cstr (void *mar, const char *str);

unsigned long mar_get_data_size (const void *mar);
void mar_set_data_size (void *mar, unsigned long v);

unsigned long mar_get_rsrc_size (const void *mar);
void mar_set_rsrc_size (void *mar, unsigned long v);

unsigned mar_get_comment_size (const void *mar);
void mar_set_comment_size (void *mar, unsigned v);

unsigned long mar_get_file_flags (const void *mar);
void mar_set_file_flags (void *mar, unsigned long v);

unsigned long mar_get_ctime (const void *mar);
void mar_set_ctime (void *mar, unsigned long v);

unsigned long mar_get_mtime (const void *mar);
void mar_set_mtime (void *mar, unsigned long v);

void mar_get_finfo (const void *mar, void *buf);
void mar_set_finfo (void *mar, const void *buf);

unsigned long mar_get_type (const void *mar);
void mar_set_type (void *mar, unsigned long v);

unsigned long mar_get_creator (const void *mar);
void mar_set_creator (void *mar, unsigned long v);

unsigned short mar_get_window_y1 (const void *mar);
void mar_set_window_y1 (void *mar, unsigned short v);

unsigned short mar_get_window_x1 (const void *mar);
void mar_set_window_x1 (void *mar, unsigned short v);

unsigned short mar_get_window_y2 (const void *mar);
void mar_set_window_y2 (void *mar, unsigned short v);

unsigned short mar_get_window_x2 (const void *mar);
void mar_set_window_x2 (void *mar, unsigned short v);

unsigned short mar_get_finder_flags (const void *mar);
void mar_set_finder_flags (void *mar, unsigned short v);

unsigned short mar_get_position_y (const void *mar);
void mar_set_position_y (void *mar, unsigned short v);

unsigned short mar_get_position_x (const void *mar);
void mar_set_position_x (void *mar, unsigned short v);

unsigned short mar_get_folder_id (const void *mar);
void mar_set_folder_id (void *mar, unsigned short v);

unsigned short mar_get_window_view (const void *mar);
void mar_set_window_view (void *mar, unsigned short v);

unsigned short mar_get_scroll_y (const void *mar);
void mar_set_scroll_y (void *mar, unsigned short v);

unsigned short mar_get_scroll_x (const void *mar);
void mar_set_scroll_x (void *mar, unsigned short v);

unsigned short mar_get_crc (const void *mar);
void mar_set_crc (void *mar);

void mar_get_macfile (const void *mar, macfile_t *mf);
void mar_set_macfile (void *mar, const macfile_t *mf);


#endif
