/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/mfs.h                                                *
 * Created:     2012-04-21 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2012 Hampa Hug <hampa@hampa.ch>                          *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_MFS_H
#define MAC_LIB_MFS_H 1


#include <stdio.h>


#define MFS_BOOT_ID 0x4c4b
#define MFS_ID      0xd2d7


typedef struct {
	FILE           *fp;

	unsigned long  offset;
	unsigned long  blocks;

	char           readonly;
	char           vinf_mod;
	char           boot_mod;
	char           volinfo_mod;
	char           altinfo_mod;

	/* points to volinfo or altinfo */
	unsigned char  *vinf;

	unsigned char  boot[1024];
	unsigned char  volinfo[64];
	unsigned short bmap[4096];
	unsigned char  altinfo[64];
} mfs_vol_t;


int mfs_open (mfs_vol_t *mfs, FILE *fp, unsigned long offset, unsigned long blocks);
int mfs_open_dc42 (mfs_vol_t *mfs, FILE *fp);
int mfs_open_auto (mfs_vol_t *mfs, FILE *fp, unsigned long offset, unsigned long blocks);
int mfs_close (mfs_vol_t *mfs, int write);

int mfs_read_block (mfs_vol_t *mfs, void *buf, unsigned long idx, unsigned long cnt);
int mfs_write_block (mfs_vol_t *mfs, const void *buf, unsigned long idx, unsigned long cnt);

void mfs_set_volinfo (mfs_vol_t *mfs, int alt);

unsigned mfs_get_id (const mfs_vol_t *mfs);
void mfs_set_id (mfs_vol_t *mfs, unsigned val);

char *mfs_get_vol_name (const mfs_vol_t *mfs);
int mfs_set_vol_name (mfs_vol_t *mfs, const char *val);

unsigned long mfs_get_ctime (const mfs_vol_t *mfs);
void mfs_set_ctime (mfs_vol_t *mfs, unsigned long val);

unsigned long mfs_get_mtime (const mfs_vol_t *mfs);
void mfs_set_mtime (mfs_vol_t *mfs, unsigned long val);

unsigned mfs_get_volume_attributes (const mfs_vol_t *mfs);
void mfs_set_volume_attributes (mfs_vol_t *mfs, unsigned val);

unsigned mfs_get_file_count (const mfs_vol_t *mfs);
void mfs_set_file_count (mfs_vol_t *mfs, unsigned val);

unsigned mfs_get_directory_start (const mfs_vol_t *mfs);
void mfs_set_directory_start (mfs_vol_t *mfs, unsigned val);

unsigned mfs_get_directory_blocks (const mfs_vol_t *mfs);
void mfs_set_directory_blocks (mfs_vol_t *mfs, unsigned val);

unsigned mfs_get_ablk_count (const mfs_vol_t *mfs);
void mfs_set_ablk_count (mfs_vol_t *mfs, unsigned val);

unsigned long mfs_get_ablk_size (const mfs_vol_t *mfs);
void mfs_set_ablk_size (mfs_vol_t *mfs, unsigned long val);

unsigned long mfs_get_clump_size (const mfs_vol_t *mfs);
void mfs_set_clump_size (mfs_vol_t *mfs, unsigned long val);

unsigned mfs_get_ablk_start (const mfs_vol_t *mfs);
void mfs_set_ablk_start (mfs_vol_t *mfs, unsigned val);

unsigned long mfs_get_next_file (const mfs_vol_t *mfs);
void mfs_set_next_file (mfs_vol_t *mfs, unsigned long val);

unsigned mfs_get_free_ablk (const mfs_vol_t *mfs);
void mfs_set_free_ablk (mfs_vol_t *mfs, unsigned val);

void mfs_update_alt_volinfo (mfs_vol_t *mfs);
void mfs_restore_alt_volinfo (mfs_vol_t *mfs);


#endif
