/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/strings.h                                            *
 * Created:     2006-12-02 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2007-2009 Hampa Hug <hampa@hampa.ch>                     *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#ifndef MAC_LIB_STRINGS_H
#define MAC_LIB_STRINGS_H 1


/*!***************************************************************************
 * @short Decode a mac string
 * @param qc A list of characters to be quoted
 *****************************************************************************/
int mac_string_decode_buf (char *dst, unsigned max,
	const unsigned char *src, unsigned cnt, const char *qc
);

/*!***************************************************************************
 * @short Decode a mac pascal string
 *****************************************************************************/
int mac_pstring_decode_buf (char *dst, unsigned max,
	const unsigned char *src, const char *qc
);

/*!***************************************************************************
 * @short Decode a mac string
 * @param qc A list of characters to be quoted
 *****************************************************************************/
char *mac_string_decode (const unsigned char *src, unsigned cnt,
	const char *qc
);

/*!***************************************************************************
 * @short Decode a mac pascal string
 * @param qc A list of characters to be quoted
 *****************************************************************************/
char *mac_pstring_decode (const unsigned char *src, const char *qc);

/*!***************************************************************************
 * @short Encode a mac string
 *****************************************************************************/
int mac_string_encode_buf (unsigned char *dst, unsigned max,
	const char *src, unsigned *cnt
);

/*!***************************************************************************
 * @short Encode a mac pascal string
 *****************************************************************************/
int mac_pstring_encode_buf (unsigned char *dst, unsigned max, const char *src);

/*!***************************************************************************
 * @short Encode a mac string
 *****************************************************************************/
unsigned char *mac_string_encode (const char *src, unsigned *cnt);

/*!***************************************************************************
 * @short Encode a mac pascal string
 *****************************************************************************/
unsigned char *mac_pstring_encode (const char *src);

/*!***************************************************************************
 * @short  Combine two path elements
 * @return str1 + "/" + str2
 *
 * The returned string is allocated with malloc(). Either str1 or str2 can
 * be the empty string.
 *****************************************************************************/
char *mac_combine_path (const char *str1, const char *str2);

/*!***************************************************************************
 * @short Get the last path component
 * @param sep The directory separator (e.g. '/')
 *****************************************************************************/
const char *mac_get_last_component (const char *str, char sep);


#endif
