/*****************************************************************************
 * mac-utils                                                                 *
 *****************************************************************************/

/*****************************************************************************
 * File name:   src/lib/unixfile.c                                           *
 * Created:     2006-08-19 by Hampa Hug <hampa@hampa.ch>                     *
 * Copyright:   (C) 2006-2009 Hampa Hug <hampa@hampa.ch>                     *
 *****************************************************************************/

/*****************************************************************************
 * This program is free software. You can redistribute it and / or modify it *
 * under the terms of the GNU General Public License version 2 as  published *
 * by the Free Software Foundation.                                          *
 *                                                                           *
 * This program is distributed in the hope  that  it  will  be  useful,  but *
 * WITHOUT  ANY   WARRANTY,   without   even   the   implied   warranty   of *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU  General *
 * Public License for more details.                                          *
 *****************************************************************************/


#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <utime.h>

#include <lib/mactime.h>
#include <lib/unixfile.h>


int uf_stat (const char *fname, unsigned long *size, unsigned long *mtime)
{
	struct stat st;

	if ((fname == NULL) || (strcmp (fname, "-") == 0)) {
		return (1);
	}

	if (stat (fname, &st) != 0) {
		return (1);
	}

	*size = (unsigned long) st.st_size;
	if ((off_t) *size != st.st_size) {
		return (1);
	}

	*mtime = mac_time_from_unix (st.st_mtime);

	return (0);
}

int uf_stat_fp (FILE *fp, unsigned long *size, unsigned long *mtime)
{
	struct stat st;

	if (fstat (fileno (fp), &st) != 0) {
		return (1);
	}

	*size = (unsigned long) st.st_size;
	if ((off_t) *size != st.st_size) {
		return (1);
	}

	*mtime = mac_time_from_unix (st.st_mtime);

	return (0);
}

unsigned long uf_get_mtime (const char *fname)
{
	struct stat st;
	time_t      tm;

	tm = time (NULL);

	if ((fname != NULL) && (strcmp (fname, "-") != 0)) {
		if (stat (fname, &st) == 0) {
			tm = st.st_mtime;
		}
	}

	return (mac_time_from_unix (tm));
}

unsigned long uf_get_mtime_fp (FILE *fp)
{
	struct stat st;
	time_t      tm;

	tm = time (NULL);

	if (fstat (fileno (fp), &st) == 0) {
		tm = st.st_mtime;
	}

	return (mac_time_from_unix (tm));
}

unsigned long uf_get_fsize (const char *fname)
{
	struct stat   st;
	unsigned long val;

	if ((fname == NULL) || (strcmp (fname, "-") == 0)) {
		return (0);
	}

	if (stat (fname, &st) != 0) {
		return (0);
	}

	val = (unsigned long) st.st_size;
	if ((off_t) val != st.st_size) {
		return (0);
	}

	return (val);
}

unsigned long uf_get_fsize_fp (FILE *fp)
{
	struct stat   st;
	unsigned long val;

	if (fstat (fileno (fp), &st) != 0) {
		return (0);
	}

	val = (unsigned long) st.st_size;
	if ((off_t) val != st.st_size) {
		return (0);
	}

	return (val);
}

int uf_set_mtime (const char *fname, unsigned long mtime)
{
	struct utimbuf buf;

	if ((fname == NULL) || (strcmp (fname, "-") == 0)) {
		return (1);
	}

	buf.actime = mac_time_to_unix (mtime);
	buf.modtime = buf.actime;

	if (utime (fname, &buf) != 0) {
		return (1);
	}

	return (0);
}
