#!/bin/bash

case "$1" in
"--help")
	echo "asenc: encode AppleSingle files"
	echo
	echo "usage: asenc [options] [file...]"
	echo "  -d, --delete  Delete source files after encoding [no]"
	exit 0
	;;

"--version")
	echo "asenc (mac-utils) version %MACUTILS_VERSION_STR"
	echo ""
	echo "Copyright (C) 2009 Hampa Hug <hampa@hampa.ch>"
	exit 0
	;;
esac

par_type=""
par_creator=""

# as_get_type file
as_get_type ()
{
	local file=$1
	local src
	local ext t c rest
	local tab

	for src in "$HOME/AppleVolumes" "$HOME/.AppleVolumes" "$HOME/applevolumes" "$HOME/.applevolumes" "/etc/netatalk/AppleVolumes.system" ; do
		if test -r "$src" ; then
			break;
		fi
	done

	if test ! -r "$src" ; then
		par_type="BINA"
		par_creator="UNIX"
		return 0
	fi

	tab=$(echo -e -n "\\t")

	while IFS=$tab read ext t c rest ; do
		case "$ext" in
		.*)
			case "$file" in
			*$ext)
				t=${t#\"}
				t=${t%\"}
				par_type=$t
				c=${c#\"}
				c=${c%\"}
				par_creator=$c
				return 0
				;;
			esac
			;;
		esac
	done < "$src"

	par_type="BINA"
	par_creator="UNIX"

	return 0
}

# as_encode file
as_encode ()
{
	local dst=$1
	local data rsrc info
	local delrsc

	if test ! -d ".mac" ; then
		mkdir -p ".mac"
	fi

	delrsc=0

	if test -f ".mac/$dst.info" ; then
		info=".mac/$dst.info"
	elif test -f ".mac/$dst.inf" ; then
		info=".mac/$dst.inf"
	else
		info=""
	fi

	if test -f "$dst" ; then
		data=$dst
	elif test -f ".mac/$dst.data" ; then
		data=".mac/$dst.data"
	else
		touch "$dst"
		data=$dst
	fi

	if test -f ".mac/$dst.rsrc" ; then
		rsrc=".mac/$dst.rsrc"
	elif test -f ".mac/$dst.rsc" ; then
		rsrc=".mac/$dst.rsc"
	elif test -f ".mac/$dst.r" ; then
		macrsc -e -i ".mac/$dst.r" -o ".mac/$dst.rsrc"
		rsrc=".mac/$dst.rsrc"
		delrsc=1
	elif test -f "$dst.rsrc" ; then
		rsrc="$dst.rsrc"
	else
		touch ".mac/$dst.rsrc"
		rsrc=".mac/$dst.rsrc"
	fi

	if test -f "$info" ; then
		if ! asng -e -b "$dst.as" -f "$data" -r "$rsrc" -n "$info" ; then
			echo "$0: error encoding $dst.as" >&2
			return 1
		fi
	else
		if test -z "$par_type" ; then
			as_get_type "$dst"
		fi

		if ! asng -e -b "$dst.as" -f "$data" -r "$rsrc" -t "$par_type" -c "$par_creator" -m "$dst" ; then
			echo "$0: error encoding $dst.as" >&2
			return 1
		fi
	fi

	touch "--reference=$data" "$dst.as" > /dev/null 2>&1

	if test "x$delrsc" = "x1" ; then
		rm -f -- "$rsrc"
	fi

	if test "x$par_del" = "x1" ; then
		rm -f -- "$data" "$rsrc" "$info"
	fi
}


par_del=0

while test $# -gt 0 ; do
	case "$1" in
	"-d" | "--delete")
		par_del=1
		;;
	-*)
		echo "$0: unknown argument ($1)" >&2
		exit 1
		;;
	*)
		if test ! -d "$1" ; then
			as_encode "$1"
		fi
		;;
	esac

	shift 1
done

for f in .mac/* ; do
	if test -f "$f" ; then
		exit 0
	fi
done

rm -rf .mac
