#!/bin/bash

case "$1" in
"--help")
	echo "macdec: decode mar files"
	echo
	echo "usage: macdec [options] [file...]"
	echo "  -d, --delete  Delete source files after decoding [no]"
	echo "  -r, --dump    Store resources as resource dump [no]"
	exit 0
	;;

"--version")
	echo "macdec (mac-utils) version %MACUTILS_VERSION_STR"
	echo ""
	echo "Copyright (C) 2011 Hampa Hug <hampa@hampa.ch>"
	exit 0
	;;
esac


mac_decode ()
{
	local src=$1
	local bas f

	if test ! -f "$src" ; then
		return 0
	fi

	if test ! -d ".mac" ; then
		mkdir ".mac"
	fi

	bas=${src%.*}

	for f in "$bas" ".mac/$bas.rsrc" ".mac/$bas.info" ".mac/$bas.r" ; do
		if test -f "$f" ; then
			echo "$0: $f exists, skipping $src" >&2
			return 1
		fi
	done

	case "$src" in
	*.mac | *.mar)
		if ! mar -d -f "$src" -d "$bas" -r ".mac/$bas.rsrc" -i ".mac/$bas.info" ; then
			echo "$0: error decoding $src" >&2
			return 1
		fi
		;;
	*.bin | *.mb)
		if ! macbin -d -b "$src" -f "$bas" -r ".mac/$bas.rsrc" -n ".mac/$bas.info" ; then
			echo "$0: error decoding $src" >&2
			return 1
		fi
		;;
	*.as | *.asf)
		if ! asng -d -b "$src" -f "$bas" -r ".mac/$bas.rsrc" -n ".mac/$bas.info" ; then
			echo "$0: error decoding $src" >&2
			return 1
		fi
		;;
	*)
		echo "$0: bad file name ($src)" >&2
		return 1
		;;
	esac

	if test "x$par_dump" = "x1" ; then
		macrsc -d -i ".mac/$bas.rsrc" -o ".mac/$bas.r"
		touch "--reference=$src" ".mac/$bas.r" > /dev/null 2>&1
		rm -f ".mac/$bas.rsrc"
	fi

	if test "x$par_del" = "x1" ; then
		rm -f "$src"
	fi
}

par_del=0
par_dump=0

while test $# -gt 0 ; do
	case "$1" in
	"-d" | "--delete")
		par_del=1
		;;
	"-r" | "--dump")
		par_dump=1
		;;
	-*)
		echo "$0: unknown argument ($1)" >&2
		exit 1
		;;
	*)
		mac_decode "$1"
		;;
	esac

	shift 1
done
