#!/bin/bash

case "$1" in
"--help")
	echo "mbdec: decode macbinary files"
	echo
	echo "usage: mbdec [options] [file.bin...]"
	echo "  -d, --delete  Delete macbinary files after decoding [no]"
	echo "  -r, --dump    Store resources as resource dump [no]"
	exit 0
	;;

"--version")
	echo "mbdec (mac-utils) version %MACUTILS_VERSION_STR"
	echo ""
	echo "Copyright (C) 2001-2009 by Hampa Hug <hampa@hampa.ch>"
	exit 0
	;;
esac


# mb_decode base
mb_decode ()
{
	local src=$1

	if test ! -f "$src.bin" ; then
		return 0
	fi

	if ! macbin -d -b "$src.bin" -f "$src" -r ".mac/$src.rsrc" -n ".mac/$src.info" ; then
		echo "$0: error decoding $src.bin" >&2
		return 1
	fi
	
	touch "--reference=$src.bin" ".mac/$src.rsrc" > /dev/null 2>&1
	touch "--reference=$src.bin" ".mac/$src.info" > /dev/null 2>&1

	if test "x$par_dump" = "x1" ; then
		macrsc -d -i ".mac/$src.rsrc" -o ".mac/$src.r"
		touch "--reference=$src.bin" ".mac/$src.r" > /dev/null 2>&1
		rm -f ".mac/$src.rsrc"
	fi

	if test "x$par_del" = "x1" ; then
		rm -f "$src.bin"
	fi
}


if test ! -d ".mac" ; then
	mkdir ".mac"
fi

par_del=0
par_dump=0

while test $# -gt 0 ; do
	case "$1" in
	"-d" | "--delete")
		par_del=1
		;;
	"-r" | "--dump")
		par_dump=1
		;;
	-*)
		echo "$0: unknown argument ($1)" >&2
		exit 1
		;;
	*.bin)
		mb_decode "${1%.bin}"
		;;
	*)
		echo "$0: bad file name ($1)" >&2
		;;
	esac

	shift 1
done
