#!/bin/bash

case "$1" in
"--help")
	echo "mbenc: encode macbinary files"
	echo
	echo "usage: mbenc [options] [file...]"
	echo "  -d, --delete  Delete files after encoding [no]"
	exit 0
	;;

"--version")
	echo "mbenc (mac-utils) version %MACUTILS_VERSION_STR"
	echo ""
	echo "Copyright (C) 2001-2009 by Hampa Hug <hampa@hampa.ch>"
	exit 0
	;;
esac


# mb_get_type file type creator
mb_get_type ()
{
	local file=$1
	local src
	local ext t c rest
	local tab

	for src in "$HOME/AppleVolumes" "$HOME/.AppleVolumes" "$HOME/applevolumes" "$HOME/.applevolumes" "/etc/netatalk/AppleVolumes.system" ; do
		if test -r "$src" ; then
			break;
		fi
	done

	if test ! -r "$src" ; then
		eval "$2=\"BINA\""
		eval "$3=\"UNIX\""
		return 0
	fi

	tab=$(echo -e -n "\\t")

	while IFS=$tab read ext t c rest ; do
		case "$ext" in
		.*)
			case "$file" in
			*$ext)
				t=${t#\"}
				t=${t%\"}
				eval "$2=\"$t\""
				c=${c#\"}
				c=${c%\"}
				eval "$3=\"$c\""
				return 0
				;;
			esac
			;;
		esac
	done < "$src"

	eval "$2=\"BINA\""
	eval "$3=\"UNIX\""
	return 0
}

# mb_encode file
mb_encode ()
{
	local dst=$1
	local data rsrc info
	local delrsc
	local type creator

	if test ! -d ".mac" ; then
		mkdir -p ".mac"
	fi

	delrsc=0

	if test -f ".mac/$dst.info" ; then
		info=".mac/$dst.info"
	elif test -f ".mac/$dst.inf" ; then
		info=".mac/$dst.inf"
	else
		info=""
	fi

	if test -f "$dst" ; then
		data=$dst
	elif test -f ".mac/$dst.data" ; then
		data=".mac/$dst.data"
	else
		touch "$dst"
		data=$dst
	fi

	if test -f ".mac/$dst.rsrc" ; then
		rsrc=".mac/$dst.rsrc"
	elif test -f ".mac/$dst.rsc" ; then
		rsrc=".mac/$dst.rsc"
	elif test -f ".mac/$dst.r" ; then
		macrsc -e -i ".mac/$dst.r" -o ".mac/$dst.rsrc"
		rsrc=".mac/$dst.rsrc"
		delrsc=1
	elif test -f "$dst.rsrc" ; then
		rsrc="$dst.rsrc"
	else
		touch ".mac/$dst.rsrc"
		rsrc=".mac/$dst.rsrc"
	fi

	if test -f "$info" ; then
		if ! macbin -e -b "$dst.bin" -f "$data" -r "$rsrc" -n "$info" ; then
			echo "$0: error encoding $dst.bin" >&2
			return 1
		fi
	else
		mb_get_type "$dst" type creator
		if ! macbin -e -b "$dst.bin" -f "$data" -r "$rsrc" -t "$type" -c "$creator" -m "$dst" ; then
			echo "$0: error encoding $dst.bin" >&2
			return 1
		fi
	fi

	mbfix -i "$dst.bin"

	if test "x$delrsc" = "x1" ; then
		rm -f -- "$rsrc"
	fi

	if test "x$par_del" = "x1" ; then
		rm -f -- "$data" "$rsrc" "$info"
	fi
}


par_del=0

while test $# -gt 0 ; do
	case "$1" in
	"-d" | "--delete")
		par_del=1
		;;
	-*)
		echo "$0: unknown argument ($1)" >&2
		exit 1
		;;
	*)
		if test ! -d "$1" ; then
			mb_encode "$1"
		fi
		;;
	esac

	shift 1
done

for f in .mac/* ; do
	if test -f "$f" ; then
		exit 0
	fi
done

rm -rf .mac
